==> myfaces-core-assembly-1.1.10-src.zip: javax/faces/el/MethodBinding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.el;

import javax.faces.context.FacesContext;

/**
 * see Javadoc of <a href="http://java.sun.com/j2ee/javaserverfaces/1.1_01/docs/api/index.html">JSF Specification</a>
 *
 * @author Thomas Spiegl (latest modification by $Author: skitching $)
 * @version $Revision: 676278 $ $Date: 2008-07-13 03:35:04 -0500 (Sun, 13 Jul 2008) $
 */
public abstract class MethodBinding
{

    // FIELDS

    // CONSTRUCTORS
    public MethodBinding()
    {
    }

    // METHODS
    
    /**
     * returns the <code>String</code> of your expression like <code>#{bean.foo}</code>.
     */
    public String getExpressionString()
    {
        return null;
    }
    
    public abstract Class getType(FacesContext facescontext) throws MethodNotFoundException;

    public abstract Object invoke(FacesContext facescontext, Object aobj[])
        throws EvaluationException, MethodNotFoundException;
}

==> myfaces-core-assembly-1.2.12-src.zip: javax/faces/el/MethodBinding.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.faces.el;

import javax.faces.context.FacesContext;

/**
 * see Javadoc of <a href="http://java.sun.com/javaee/javaserverfaces/1.2/docs/api/index.html">JSF Specification</a>
 *
 * @author Thomas Spiegl (latest modification by $Author: skitching $)
 * @version $Revision: 676298 $ $Date: 2008-07-13 05:31:48 -0500 (Sun, 13 Jul 2008) $
 * @deprecated
 */
public abstract class MethodBinding
{

    // FIELDS

    // CONSTRUCTORS
        /**
         * @deprecated
         */
    public MethodBinding()
    {
    }

    // METHODS
    
    /**
     * returns the <code>String</code> of your expression like <code>#{bean.foo}</code>.
         * @deprecated
     */
    public String getExpressionString()
    {
        return null;
    }
    
    /**
     * @deprecated
     */
    public abstract Class getType(FacesContext facescontext) throws MethodNotFoundException;

    /**
     * @deprecated
     */
    public abstract Object invoke(FacesContext facescontext, Object aobj[])
        throws EvaluationException, MethodNotFoundException;
}
